export declare enum ExternalActionType {
    OPENED_DOCUMENT = "OPENED_DOCUMENT",
    CONTENT_CHANGED = "CONTENT_CHANGED",
    CONFIG_CHANGED = "CONFIG_CHANGED"
}
declare type BaseAction<TType extends ExternalActionType, TPayload = undefined> = {
    type: TType;
    payload: TPayload;
};
declare type ContentChange = {
    rangeOffset: number;
    rangeLength: number;
    text: string;
};
export declare type ContentChanged = BaseAction<ExternalActionType.CONTENT_CHANGED, {
    fileUri: string;
    changes: ContentChange[];
}>;
export declare type OpenedDocument = BaseAction<ExternalActionType.OPENED_DOCUMENT, {
    fileUri: string;
    content: string;
}>;
export declare type ConfigChanged = BaseAction<ExternalActionType.CONFIG_CHANGED, {
    browserstackCredentials: {
        username: string;
        password: string;
    };
}>;
export declare const contentChanged: (payload: {
    fileUri: string;
    changes: ContentChange[];
}) => {
    type: ExternalActionType.CONTENT_CHANGED;
    payload: {
        fileUri: string;
        changes: ContentChange[];
    };
};
export declare const openedDocument: (payload: {
    fileUri: string;
    content: string;
}) => {
    type: ExternalActionType.OPENED_DOCUMENT;
    payload: {
        fileUri: string;
        content: string;
    };
};
export declare const configChanged: (payload: {
    browserstackCredentials: {
        username: string;
        password: string;
    };
}) => {
    type: ExternalActionType.CONFIG_CHANGED;
    payload: {
        browserstackCredentials: {
            username: string;
            password: string;
        };
    };
};
export declare type ExternalAction = OpenedDocument | ContentChanged | ConfigChanged;
export {};
